Bravura is a SMuFL-compliant music font created by Steinberg Media. It's hosted upstream [here](https://github.com/steinbergmedia/bravura).

`bravura_metadata.json` has been slightly modified so that the codepoints, written "U+0000" upstream, are written "\u0000". This allows direct use as unicode characters without preprocessing.
